@@ -746,8 +746,8 @@ sub commit {
                           aid => $self->act_obj->aid,
                           code => $self->act_obj->code,
                           intvl => $tempintvl->intvl,
-                          long_desc => $self->long_desc || 'FILLUP',
-                          long_desc => $self->remark || 'FILLUP',
+                          long_desc => $self->long_desc,
+                          remark => $self->remark || 'fillup',
                           partial => 0,
                       );
 
@@ -793,7 +793,7 @@ sub commit {
             count => $count, 
         );
     }
-    return $CELL->status_notice( 'DISPATCH_FILLUP_NO_INTERVALS_CREATED' );
+    return $CELL->status_ok( 'DISPATCH_FILLUP_NO_INTERVALS_CREATED', count => 0 );
 }
 
 # given a tempintvl object, clobbers any intervals that conflict with it,
